@@ -6,12 +6,18 @@
 ##' @param sigma sigma parameter
 ##' @param phi phi parameter
 ##' @param theta this is 'beta' parameter in Brix and Diggle (2001)
+##' @param mu the mean of the latent field, if equal to NULL, this is set to -sigma^2/2
 ##' @param beta ONLY USED IN case where there is covariate information.
 ##' @seealso \link{lgcpPredict}
 ##' @export
 
-lgcppars <- function(sigma=NULL,phi=NULL,theta=NULL,beta=NULL){
+lgcppars <- function(sigma=NULL,phi=NULL,theta=NULL,mu=NULL,beta=NULL){
     
-	return(list(sigma=sigma,phi=phi,mu=-0.5*sigma^2,theta=theta,beta=beta))	
+    if(is.null(mu)){
+	    return(list(sigma=sigma,phi=phi,mu=-0.5*sigma^2,theta=theta,beta=beta))
+	}
+	else{
+	    return(list(sigma=sigma,phi=phi,mu=mu,theta=theta,beta=beta))
+	}	
 	# NB choice of parameter mu=-0.5*sigma^2 gives mean(exp(Y)) = 1  					
 }						
