@@ -1,5 +1,5 @@
 library(lgcp)
-library(spatstat)
+library(spatstat.core)
 
 xyt <- cbind(matrix(runif(200,-5,5),100,2),runif(100,0,5))
 tlim <- c(0,5) 
@@ -15,4 +15,4 @@ mstppp3 <- mstppp(ST,data=data)
 
 plot(mstppp1,cols=grey(mstppp1$data[,1]/max(mstppp1$data[,1])))
 
-pppver <- as.ppp(mstppp1)
\ No newline at end of file
+pppver <- as.ppp(mstppp1)
